@@ -15,7 +15,7 @@ class DareDIDL(DIDL):
 
     def __init__(self, prefix, config, db):
         super(DareDIDL, self).__init__(prefix, config, db)
-        self.prefix = 'didl'
+        self.prefix = 'nl_didl'
 
     def __call__(self, element, metadata):
         super(DareDIDL, self).__call__(element, metadata)
